<?php

/*
Events :
************
These are events of the game you can intercept in the plugin (for example: a player cross a CP)
Events list : http://www.undef.name/Development/Events.php#DescriptionXAseco2

Methods :
*************
These are functions allowing the plugin to perform an action on the game (for example : restart the map)
Methods list : http://methods.xaseco.org/methodstmc.php
Call a method : $aseco->client->query("NameOfTheMethod", para1, para2,...);
For example, kick the player $login : $aseco->client->query("Kick", $login);

The $aseco object :
****************
It's the object managed by Xaseco including (allmost) all the parameters of the server.
It is given as argument in every events, and we often have to give it as argument in our functions.
To explore $aseco (choose Xaseco2) : http://koti.mbnet.fi/reaby/tmn/xaseco/explorer/
(The most useful datas are in $aseco->server)


Other useful and even indispensable links :
**********************************************
The php guide : http://php.net/manual/en/
Many tips and tricks in the "Development" tab : http://www.undef.name/
Manialinks in detail : http://forum.funtrackers.net/showthread.php?tid=607&pid=12552#change
Xaseco : http://www.xaseco.org/

Created by Claude, translated by Palteza.
*/

/*
Id Manialinks
id="3121120001"	= welcome message
id="3121120002"	= display of the map name

Id Actions
action="5191520001"	= 	closing of the welcome message
*/

// The most useful events
Aseco::registerEvent('onStartup', 'b_onStartup');
Aseco::registerEvent('onPlayerConnect', 'b_onPlayerConnect');
Aseco::registerEvent('onPlayerDisconnect', 'b_onPlayerDisconnect');
Aseco::registerEvent('onBeginMap', 'b_onBeginMap');
Aseco::registerEvent('onEndMap', 'b_onEndMap');
Aseco::registerEvent('onBeginRound', 'b_onBeginRound');
Aseco::registerEvent('onEndRound', 'b_onEndRound');
Aseco::registerEvent('onCheckpoint', 'b_onCheckpoint');
Aseco::registerEvent('onPlayerFinish', 'b_onPlayerFinish');
Aseco::registerEvent('onPlayerInfoChanged', 'b_onPlayerInfoChanged');

Aseco::registerEvent('onPlayerManialinkPageAnswer', 'b_gestaction');


//********* Event onStartup *************************************************
//** When : At the plugin launch ****************************************
//** Allow the initialization of the plugin (example : xml initialization reading) **
function b_onStartup($aseco) {
	
//	if (file_exists('initmyplugin.xml')) $xmlt = simplexml_load_file('initmyplugin.xml');
//...
}


//********* Event onPlayerConnect ******************************************************
//** When : At the aseco launch *******
//** When : At the aseco launch for each player, when a player is connecting on the serv *******
//** Allow the player initialization. For example : the display of the plugin buttons **
//** to see the structure of $player : http://koti.mbnet.fi/reaby/tmn/xaseco/explorer/ *****
function b_onPlayerConnect($aseco, $player) {
	
	$login = $player->login;
	$nick = $player->nickname;
	
	//Display of a welcome in game
	//To know everything on manialinks, watch there : http://forum.funtrackers.net/showthread.php?tid=607&pid=12552#change
	$xml  = '<manialink version="1" id="3121120001">';
	$xml .= '<frame posn="0 0 0">';
	//for styles and sub-styles, see there : maniaplanet:///:exemple
	$xml .= '<quad posn="0 0 0" sizen="120 15" halign="center" valign="center" style="Bgs1" substyle="BgList"/>';
	$text = '$0ffHello '.$nick;
	$xml .= '<label posn="0 2 1" halign="center" valign="center" text="'.$text.'"/>';
	$xml .= '<quad posn="0 -4 1" sizen="10 10" halign="center" valign="center" style="Icons64x64_1" substyle="Close" action="5191520001"/>';

	$xml .= '</frame>';
	$xml .= '</manialink>';
	$aseco->client->query("SendDisplayManialinkPageToLogin", $login, $xml, 0, false);
	// SendDisplayManialinkPageToLogin is a method. To see every TM methods, go there : http://methods.xaseco.org/methodstmc.php
}


//******** When : At the player disconnection ****************************************
function b_onPlayerDisconnect($aseco, $player) {

}


//********* Event onBeginMap *****************************************************
//** When : At the aseco launch, at the loading of the map **************
//** To see the structure of $map : http://koti.mbnet.fi/reaby/tmn/xaseco/explorer/ **
function b_onBeginMap($aseco, $map) {

	$nomMap = $map->name;

	//in this example the name of the map is shown to all the players during 5 seconds
	$xml  = '<manialink version="1" id="3121120002">';
	$xml .= '<frame posn="0 50 0">';
	$xml .= '<quad posn="0 0 0" sizen="120 10" halign="center" valign="center" style="Bgs1" substyle="BgList"/>';
	$xml .= '<label posn="0 0 1" halign="center" valign="center" text="'.$nomMap.'"/>';
	$xml .= '</frame>';
	$xml .= '</manialink>';
	$aseco->client->query("SendDisplayManialinkPage", $xml, 5000, false);
}


//********* Event onEndMap *****************************************************
//** When : At the end of the map ************************************************
//** $race : array(5) I never used this one ****************************
function b_onEndMap($aseco, $race) {

// Never used the $race variable. It's a array(5) for which i don't know the details
// We can see it and work on its values in the console with this line :
//	var_dump($race);

}


//********* Event onBeginRound *****************************************************
//** When : At the start of the time ************************************************
function b_onBeginRound($aseco) {

}


//********* Event onEndRound *****************************************************
//** When : At the end of a round (WU, del, restart, nextmap, all included) ********
function b_onEndRound($aseco) {

}


//********* Event onCheckpoint *********************************************************************************************
//** When : When a player cross a CP *******************************************************************************
//** This is the event to use for an endurance plugin for example (where you have to count the CP crossed by players) **********************************************
//** Warning, this event is happening DURING the race. Limit an excessive use of manialinks, disk writings, or you'll cause lags on the server **
function b_onCheckpoint($aseco, $checkpoint) {
/*
$checkpoint[0] = player identity
$checkpoint[1] = player login
$checkpoint[2] = time in milliseconds (in laps mode, it's the time since the last start bloc crossing)
$checkpoint[3] = laps mode only : number of laps
$checkpoint[4] = number of crossed CPs since the start
*/
}


//********* Event onPlayerFinish **********************************
//** When : Each time a player is crossing the finish line ********
function b_onPlayerFinish($aseco, $finish) {

/*
objet $finish :
$finish->$player
$finish->$map
$finish->$score (time)
$finish->$date
$finish->checks = array of time at CP
$finish->$new ? never used
$finish->$pos ? never used

Example :
*/
	$login = $finish->player->login;
	$time = $finish->score;

}


//********* Event onPlayerInfoChanged *************************************************************
//** When : A player is moving from spect to player (and vice versa), or when he switches team **
function b_onPlayerInfoChanged($aseco, $changes) {

/*
array $changes :
	["Login"]
	["NickName"]
	["PlayerId"]
	["TeamId"]
	["SpectatorStatus"]
	["LadderRanking"]
	("Flags"]

Example :
*/
	$login = $changes["Login"];
}

	
//*********** action onPlayerManialinkPageAnswer *****************************************************
//** This is here you have to treat the players actions on the manialinks for those on which we defined an action **
function b_gestaction($aseco, $command) {

	$login = $command[1]; 
	$action = (string)$command[2];
	
	// Closing of welcome message
	if ($action == '5191520001') {
		$xml  = '<manialink version="1" id="3121120001">';
		$xml .= '</manialink>';
		$aseco->client->query("SendDisplayManialinkPageToLogin", $login, $xml, 0, false);
	}
}

?>
